KeyStepKind

Enum KeyStepKind 

pub enum KeyStepKind {
    Down,
    Up,
    Press,
}
What kind of key event this step is.

Variants



Down

Key press (keydown).



Up

Key release (keyup).



Press

A composite press — engines that don’t have separate keydown/ keyup paths can use this. We emit explicit Down + Up for trusted paths and never use Press directly, but it’s part of the public type for engines that need it.